@@ -30,15 +30,11 @@ class SQLServer(Abstract_DB):
         pyodbc_drivers = [dri for dri in pyodbc.drivers() if "SQL Server" in dri]
         if pyodbc_drivers:
             driver = pyodbc_drivers[0]
-        if s.get("DRIVER", None):
-            driver = s.driver
-        driver_str = "Driver={" + driver + "};"
 
         connection = pyodbc.connect(
-            f"{driver_str}"
-            f"Server={s.ip};"
-            f"Database={s.base};"
-            f"UID={s.user};"
-            f"PWD={s.password};"
+            "Trusted_Connection=yes",
+            driver="{" + driver + "}",
+            server=s.ip,
+            database=s.base,
         )
         return connection.cursor()
